Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(87)

Unified Diff: ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h

Issue 2751713002: Fetch Suggestions by category (Closed)
Patch Set: git cl web Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h
diff --git a/ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h b/ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h
index 7c163787f9d705349c865f937a2b0bc0fcb98731..b34ba83d6225d67ec9a207d565075613d9c0a90f 100644
--- a/ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h
+++ b/ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h
@@ -12,8 +12,10 @@
// to be pulled.
@protocol ContentSuggestionsDataSink
-// Notifies the Data Sink that new data is available.
-- (void)dataAvailable;
+// Notifies the Data Sink that new data is available for the section identified
+// by |sectionInfo|.
+- (void)dataAvailableForSection:
+ (ContentSuggestionsSectionInformation*)sectionInfo;
// The suggestion associated with |suggestionIdentifier| has been invalidated by
// the backend data source and should be cleared now. This is why this method is

Powered by Google App Engine
This is Rietveld 408576698